@@ -313,7 +313,7 @@ void ENVIRONMENT::initialise ()
     }
   for (int count = 0; count < MAX_OBJECTS; count++)
     objects[count] = NULL;
-  for (int count = 0; count < MAXPLAYERS * 3; count++)
+  for (int count = 0; count < MAXPLAYERS; count++)
     order[count] = NULL;
 
   clear_to_color (sky, PINK);
@@ -378,7 +378,7 @@ int ENVIRONMENT::removeObject (VIRTUAL_OBJECT *object)
     {
       objects[objCount] = NULL;
       if (objClass == TANK_CLASS)
-        for (int ordCount = 0; ordCount < _global->maxNumTanks; ordCount++)
+        for (int ordCount = 0; ordCount < MAXPLAYERS; ordCount++)
           if (order[ordCount] == object)
             order[ordCount] = NULL;
     }
@@ -479,7 +479,7 @@ int ENVIRONMENT::ingamemenu ()
       if (keypressed ())
         {
           k = readkey ();
-          if (k >> 8 == KEY_ESC)
+          if (k >> 8 == KEY_ESC || k >> 8 == KEY_P)
             return (0);
         }
 
@@ -573,6 +573,20 @@ void ENVIRONMENT::replaceCanvas ()
           blit (sky, db, _global->lastUpdates[count].x, _global->lastUpdates[count].y - MENUHEIGHT, _global->lastUpdates[count].x, _global->lastUpdates[count].y, _global->lastUpdates[count].w, _global->lastUpdates[count].h);
           masked_blit (terrain, db, _global->lastUpdates[count].x, _global->lastUpdates[count].y, _global->lastUpdates[count].x, _global->lastUpdates[count].y, _global->lastUpdates[count].w, _global->lastUpdates[count].h);
         }
+          #ifdef NEW_GAMELOOP
+          int iLeft = 0;
+          int iRight = _global->screenWidth - 1;
+          int iTop = MENUHEIGHT;
+          int iBottom = _global->screenHeight - 1;
+
+          vline(db, iLeft, iTop, iBottom, wallColour);    // Left edge
+          vline(db, iLeft + 1, iTop, iBottom, wallColour);    // Left edge
+          vline(db, iRight, iTop, iBottom, wallColour);   // right edge
+          vline(db, iRight - 1, iTop, iBottom, wallColour);   // right edge
+          hline(db, iLeft, iBottom, iRight, wallColour);// bottom edge
+          if (_global->bIsBoxed)
+              hline(db, iLeft, iTop, iRight, wallColour);// top edge
+          #endif
       _global->lastUpdatesCount = 0;
       // The menu needs to be redrawn:
       make_update(0, 0, _global->screenWidth - 1, MENUHEIGHT);
@@ -985,3 +999,70 @@ void ENVIRONMENT::Reset_Options()
 }
 
 
+/*
+This function checks to see which wall type we are using
+and sets the appropriate colour.
+*/
+void ENVIRONMENT::Set_Wall_Colour()
+{
+    switch (current_wallType)
+    {
+       case WALL_RUBBER:
+          wallColour = makecol(0, 255, 0); break;
+       case WALL_STEEL:
+          wallColour = makecol(255, 0, 0); break;
+       case WALL_SPRING:
+          wallColour = makecol(0, 0, 255); break;
+       case WALL_WRAP:
+          wallColour = makecol(255, 255, 0); break;
+    }
+}
+
+
+
+bool ENVIRONMENT::Get_Boxed_Mode(GLOBALDATA *global)
+{
+    if (dBoxedMode == 2.0)
+    {
+       if (rand() % 2)
+          global->bIsBoxed = true;
+       else
+          global->bIsBoxed = false;
+    }
+    else if (dBoxedMode == 1.0)
+         global->bIsBoxed = true;
+    else if (dBoxedMode == 0.0)
+         global->bIsBoxed = false;
+    return global->bIsBoxed;
+} 
+
+
+
+TANK *ENVIRONMENT::Get_Next_Tank(int *wrapped_around)
+{
+   static int index = 0;
+   int found = FALSE;
+   int old_index;
+
+   old_index = index;
+   do
+   {
+      index++;
+      if (index >= MAXPLAYERS)
+      {
+         index = 0;
+         *wrapped_around = TRUE;
+      }
+      if (order[index])
+          found = TRUE;      // found a tank
+   } while ( (! found) && (old_index != index) );
+ 
+   /* 
+   if (! found)
+      *wrapped_around = TRUE;
+   else
+      *wrapped_around = FALSE;
+   */
+   return order[index];
+}
+
