@@ -61,6 +61,7 @@ enum wallTypes
 
 // stages
 #define STAGE_AIM 0
+#define STAGE_FIRE 1
 #define STAGE_ENDGAME 3
 
 
@@ -161,6 +162,9 @@ class ENVIRONMENT
     int loadFromFile (ifstream &ifsFile);
 
     void Reset_Options();
+    void Set_Wall_Colour();
+    bool Get_Boxed_Mode(GLOBALDATA *global);
+    TANK *Get_Next_Tank(int *wrapped_around);
   };
 
 #endif
