@@ -1,3 +1,4 @@
+#include <sys/stat.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -529,6 +530,8 @@ int Load_Weapons_Text(GLOBALDATA *global)
     sprintf(path_to_file, "%s/text/weapons_sk.txt", global->dataDir);
   else if (global->language == LANGUAGE_RUSSIAN)
     sprintf(path_to_file, "%s/text/weapons_ru.txt", global->dataDir);
+  else if (global->language == LANGUAGE_SPANISH)
+    sprintf(path_to_file, "%s/text/weapons_ES.txt", global->dataDir);
 
   // open file
   wfile = fopen(path_to_file, "r");
