@@ -22,7 +22,7 @@
 #include "globaldata.h"
 #include "files.h"
 #include "network.h"
-
+#include "team.h"
 
 GLOBALDATA::GLOBALDATA ():dataDir(NULL),configDir(NULL),updates(NULL),lastUpdates(NULL),allPlayers(NULL),
     players(NULL),currTank(NULL),saved_game_list(NULL)
@@ -953,6 +953,8 @@ int GLOBALDATA::Load_Text_Files()
 
     if (language == LANGUAGE_RUSSIAN)
        sprintf(filename, "%s/text/war_quotes_ru.txt", dataDir);
+    else if (language == LANGUAGE_SPANISH)
+       sprintf(filename, "%s/text/war_quotes_ES.txt", dataDir);
     else
        sprintf(filename, "%s/text/war_quotes.txt", dataDir);
     war_quotes = new TEXTBLOCK(filename);
@@ -967,6 +969,8 @@ int GLOBALDATA::Load_Text_Files()
         strcpy(suffix, "_sk.txt");
      else if (language == LANGUAGE_RUSSIAN)
         strcpy(suffix, "_ru.txt");
+     else if (language == LANGUAGE_SPANISH)
+        strcpy(suffix, "_ES.txt");
      else
         strcpy(suffix, ".txt");       // default to english
 
@@ -1055,3 +1059,119 @@ int GLOBALDATA::Find_Data_Dir()
 }
 
 
+
+/*
+Find the max velocity of a missile
+*/
+double GLOBALDATA::Calc_Max_Velocity()
+{
+   dMaxVelocity = (double) MAX_POWER * (100.0 / (double) frames_per_second) / 100.0;
+   return dMaxVelocity; 
+}
+
+
+
+/* See how many humans and networked players we have */
+int GLOBALDATA::Count_Humans()
+{
+     int count;
+     int humans = 0;
+
+     for (count = 0; count < numPlayers; count++)
+     {
+        if (players[count]->type == HUMAN_PLAYER)
+           humans++;
+        else if (players[count]->type == NETWORK_CLIENT)
+           humans++;
+     }
+
+     return humans;
+}
+
+
+/*
+This function checks to see if there is a single player left standing.
+If there is, that player's index is returned. If there is no winner, then
+-1 is returned. If all tanks have been destroyed, then -2 is returned.
+*/
+int GLOBALDATA::Check_For_Winner()
+{
+    int index = 0, tank_count = 0;
+    int last_alive = -1;
+    
+    while ( (index < numPlayers) && (tank_count < 2) )
+    {
+         if (players[index]->tank)
+         {
+            last_alive = index;
+            tank_count++;
+         }
+         index++;
+    }
+
+    if ( (last_alive >= 0) && (tank_count == 1) )
+       return last_alive;
+    else if (tank_count > 1)
+       return -1;
+    else      // all dead
+       return -2;
+}
+
+
+/*
+This function gives credits, score and money to the winner(s).
+*/
+void GLOBALDATA::Credit_Winners(int winner)
+{
+   int team_members = 0;
+   int index;
+
+   if (winner <= 0)    // no winner
+      return;
+
+   if (winner == JEDI_WIN)
+   {
+      for (index = 0; index < numPlayers; index++)
+      {
+          if (players[index]->team == TEAM_JEDI)
+          {
+             players[index]->score++;
+             players[index]->won++;
+             team_members++;
+          }
+      }
+
+   }
+
+   else if (winner == SITH_WIN)
+   {
+       for (index = 0; index < numPlayers; index++)
+       {
+          if (players[index]->team == TEAM_SITH)
+          {
+             players[index]->score++;
+             players[index]->won++;
+             team_members++;
+          }
+       }
+   }
+   else // credit single winner
+   {
+      players[winner]->score++;
+      players[winner]->won++;
+      players[winner]->money += (int) scoreRoundWinBonus; 
+   }
+
+   // team gets their money too
+   if (team_members)
+   {
+       int team_bonus = (int) scoreRoundWinBonus / team_members;
+       for (index = 0; index < numPlayers; index++)
+       {
+           if ( ((winner == JEDI_WIN) && (players[index]->team == TEAM_JEDI) ) ||
+                ((winner == SITH_WIN) && (players[index]->team == TEAM_SITH) ) )
+                players[index]->money += team_bonus;
+       }
+   }
+}
+
