@@ -34,6 +34,7 @@
 #define LANGUAGE_GERMAN 3.0
 #define LANGUAGE_SLOVAK 4.0
 #define LANGUAGE_RUSSIAN 5.0
+#define LANGUAGE_SPANISH 6.0
 
 #define COLOUR_THEME_REGULAR 0.0
 #define COLOUR_THEME_CRISPY 1.0
@@ -211,7 +212,11 @@ class GLOBALDATA
 #ifdef DEBUG_AIM_SHOW
     bool bASD;
 #endif
-    int Find_Data_Dir();   
+    int Find_Data_Dir();
+    double Calc_Max_Velocity();
+    int Count_Humans();
+    int Check_For_Winner();    // returns winner index or -1 for no winner
+    void Credit_Winners(int winner);
   };
 
 #endif
