@@ -21,7 +21,7 @@
  * */
 
 #ifndef VERSION
-#define VERSION "4.5"
+#define VERSION "4.6"
 #endif
 
 #ifdef GENTOO
@@ -61,6 +61,8 @@
 
 #include <string>
 
+#define GAME_SPEED 14000
+
 #ifdef LINUX
 #define LINUX_SLEEP usleep(10000)
 #define LINUX_REST usleep(40000)
@@ -149,6 +151,7 @@ using namespace std;
 #define SHIELDS 6
 #define WEAPONSOUNDS 4
 #define NAME_LENGTH 24
+#define ADDRESS_LENGTH 16
 
 //Score coeficients
 
@@ -180,7 +183,11 @@ using namespace std;
 #define BACKGROUND_LINE 1
 #define BACKGROUND_BLANK 2
 
+#ifdef NEW_GAMELOOP
+#define WAIT_AT_END_OF_ROUND 300
+#else
 #define WAIT_AT_END_OF_ROUND 100
+#endif
 
 // time between volly shots
 #define VOLLY_DELAY 50
