@@ -28,7 +28,7 @@ char *mouseText[2] = { "Custom", "Default"};
 char *meteorText[4] = { "Off", "Light", "Heavy", "Lethal"};
 char *lightningText[4] = { "Off", "Weak", "Energetic", "Violent"};
 char *laserSatelliteText[4] = { "Off", "Weak", "Strong", "Super"};
-char *languageText[6] = { "English", "Português", "Français", "Deutsch", "Slovak", "Russian"};
+char *languageText[7] = { "English", "Português", "Français", "Deutsch", "Slovak", "Russian", "Spanish"};
 char *colourText[2] = { "Regular", "Crispy"};
 char *landTypeText[8] = { "Random", "Canyons", "Mountains", "Valleys", "Hills", "Foothills", "Plains", "None" };
 char *turnTypeText[4] = { "High+", "Low+", "Random", "Simul" };
@@ -45,7 +45,7 @@ char *mouseText_ptbr[2] = { "Personalizado", "PadrÃ£o"};
 char *meteorText_ptbr[4] = { "Desligado", "Fraco", "Forte", "Letal"};
 char *lightningText_ptbr[4] = { "Desligado", "Fraco", "EnergÃ©tico", "Violento"};
 char *laserSatelliteText_ptbr[4] = { "Desligado", "Fraco", "Forte", "Super"};
-char *languageText_ptbr[6] = { "English", "Português", "Français", "Deutsch", "Slovak", "Russian"};
+char *languageText_ptbr[7] = { "English", "Português", "Français", "Deutsch", "Slovak", "Russian", "Spanish"};
 char *colourText_ptbr[2] = { "Regular", "Crispy"};
 char *landTypeText_ptbr[8] = { "aleatÃ³rio", "Canyons", "Montanhas", "Vales", "Colinas", "Morros", "Planos", "Nenhum" };
 char *turnTypeText_ptbr[4] = { "Melhores+", "Piores+", "AleatÃ³rio", "Simul" };
@@ -62,7 +62,7 @@ char *mouseText_fr[2] = { "Pesonnel", "Défaut"};
 char *meteorText_fr[4] = { "Off", "Light", "Heavy", "Lethal"};
 char *lightningText_fr[4] = { "Aucun", "Faible", "Energique", "Violent"};
 char *laserSatelliteText_fr[4] = { "Aucun", "Faible", "Fort", "Super"};
-char *languageText_fr[6] = { "English", "Português", "Français", "Deutsch", "Slovak", "Russian"};
+char *languageText_fr[7] = { "English", "Português", "Français", "Deutsch", "Slovak", "Russian", "Spanish"};
 char *colourText_fr[2] = { "Régulier", "Croustillant"};
 char *landTypeText_fr[8] = { "Aléatoire", "Canyons", "Mountagnes", "Vallées", "Collines", "Contreforts", "Plaines", "Aucun" };
 char *turnTypeText_fr[4] = { "Haut", "Bas", "Aléatoire", "Simulé" };
@@ -78,7 +78,7 @@ char *mouseText_de[2] = { "Angepasst", "Standard"};
 char *meteorText_de[4] = { "Aus", "Leicht", "Schwer", "Tödlich"};
 char *lightningText_de[4] = { "Aus", "Schwach", "Stark", "Brutal"};
 char *laserSatelliteText_de[4] = { "Aus", "Schwach", "Stark", "Super"};
-char *languageText_de[6] = { "English", "Português", "Français", "Deutsch", "Slovak", "Russian"};
+char *languageText_de[7] = { "English", "Português", "Français", "Deutsch", "Slovak", "Russian", "Spanish"};
 char *colourText_de[2] = { "Normal", "Kontrastreich"};
 char *landTypeText_de[8] = { "Zufällig", "Canyons", "Berge", "Täler", "Hügel", "Flache Hügel", "Ebene", "Nichts" };
 char *turnTypeText_de[4] = { "Hoch+", "Niedrig+", "Zufällig", "Simul" };
@@ -93,7 +93,7 @@ char *mouseText_sk[2] = { "Vlastné", "Východzie"};
 char *meteorText_sk[4] = { "Vypnuté", "Ľahké", "Ťažké", "Smrteľné"};
 char *lightningText_sk[4] = { "Vypnuté", "Slabé", "Energetické", "Kruté"};
 char *laserSatelliteText_sk[4] = { "Vypnutý", "Slabý", "Silný", "Super"};
-char *languageText_sk[6] = { "Anglicky", "Portugalsky", "Francúzsky", "Nemecky", "Slovensky", "Rusky"};
+char *languageText_sk[7] = { "Anglicky", "Portugalsky", "Francúzsky", "Nemecky", "Slovensky", "Rusky", "Spanish"};
 char *colourText_sk[2] = { "Normálna", "Svieža"};
 char *landTypeText_sk[8] = { "Náhodná", "Kaňony", "Hory", "Údolia", "Kopce", "Úpätia", "Nížiny", "Žiadna" };
 char *turnTypeText_sk[4] = { "Vysoký+", "Nízky+", "Náhodný", "Simul" };
@@ -108,7 +108,7 @@ char *mouseText_ru[2] = { "Собственный", "По умолчанию"};
 char *meteorText_ru[4] = { "Нет", "Слабый", "Сильный", "Смертельный"};
 char *lightningText_ru[4] = { "Нет", "Слабые", "Сильные", "Мощные"};
 char *laserSatelliteText_ru[4] = { "Нет", "Слабые", "Сильные", "Супер!!"};
-char *languageText_ru[6] = { "English", "Português", "Français", "Deutsch", "Slovak", "Русский"};
+char *languageText_ru[7] = { "English", "Português", "Français", "Deutsch", "Slovak", "Русский", "Spanish"};
 char *colourText_ru[2] = { "Обычная", "Четкая"};
 char *landTypeText_ru[8] = { "Случайный", "Каньоны", "Горы", "Возвышенность", "Холмы", "Предгорья", "Равнины", "Выкл." };
 char *turnTypeText_ru[4] = { "Сильные +", "Слабые +", "Случайно", "Все сразу" };
@@ -120,7 +120,7 @@ char *skipTypeText_ru[2] = { "Выкл.", "Вкл."};
 // declare variables
 MENUDESC mainMenu;
 
-if (global->language == LANGUAGE_ENGLISH)
+if ( (global->language == LANGUAGE_ENGLISH) || (global->language == LANGUAGE_SPANISH) )
   {
     MENUENTRY physicsOpts[8] =
     {
@@ -133,7 +133,7 @@ if (global->language == LANGUAGE_ENGLISH)
       { "Violent Death", NULL, WHITE, &global->violent_death, NULL, "%s", 0, 3, 1, 0, lightningText, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 40},
       { "Timed Shots", NULL, WHITE, &global->max_fire_time, NULL, "%3.0f", 0, 180, 5, 0, NULL, OPTION_DOUBLETYPE, FALSE, global->halfWidth - 3, global->halfHeight + 60}
     };
-    MENUDESC physicsMenu = { "Physics", 7, physicsOpts, TRUE, FALSE};
+    MENUDESC physicsMenu = { "Physics", 8, physicsOpts, TRUE, FALSE};
 
     MENUENTRY weatherOpts[7] =
     {
@@ -218,7 +218,7 @@ if (global->language == LANGUAGE_ENGLISH)
       { "Landscape", NULL, WHITE, (double*)&env->landType, NULL, "%s", 0, 7, 1, LANDTYPE_HILLS, landTypeText, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 72},
       { "Turn Order", NULL, WHITE, (double*)&global->turntype, NULL, "%s", 0, 3, 1, TURN_RANDOM, turnTypeText, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 92},
       { "Skip AI-only play", NULL, WHITE, &global->skipComputerPlay, NULL, "%s", 0, 1, 1, 1, skipTypeText, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 112},
-      { "Language", NULL, WHITE, &global->language, NULL, "%s", 0, 5, 1, 0, languageText, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 132}
+      { "Language", NULL, WHITE, &global->language, NULL, "%s", 0, 6, 1, 0, languageText, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 132}
     };
 // mainMenu = { "Main Menu", 10, mainOpts, TRUE, FALSE};
     mainMenu.title = "Main Menu";
@@ -388,7 +388,7 @@ if (global->language == LANGUAGE_PORTUGUESE)  // Portuguese
       { "Pular Jogo SÃ³ com RobÃ´s", NULL, WHITE, &global->skipComputerPlay,
         NULL, "%s", 0, 2, 1, 1, skipTypeText_ptbr, OPTION_SPECIALTYPE, FALSE,
         global->halfWidth - 3, global->halfHeight + 112},
-      { "língua", NULL, WHITE, &global->language, NULL, "%s", 0, 5, 1, 0, languageText_ptbr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 132}
+      { "língua", NULL, WHITE, &global->language, NULL, "%s", 0, 6, 1, 0, languageText_ptbr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 132}
 
     };
 // mainMenu = { "Menu Principal", 10, mainOpts, TRUE, FALSE};
@@ -501,7 +501,7 @@ if (global->language == LANGUAGE_FRENCH)
       { "Paysage", NULL, WHITE, (double*)&env->landType, NULL, "%s", 0, 7, 1, LANDTYPE_HILLS, landTypeText_fr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 72},
       { "Ordre de passage", NULL, WHITE, (double*)&global->turntype, NULL, "%s", 0, 3, 1, TURN_RANDOM, turnTypeText_fr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 92},
       { "Jeu IA seule", NULL, WHITE, &global->skipComputerPlay, NULL, "%s", 0, 1, 1, 1, skipTypeText_fr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 112},
-      { "Langue", NULL, WHITE, &global->language, NULL, "%s", 0, 5, 1, 0, languageText_fr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 132}
+      { "Langue", NULL, WHITE, &global->language, NULL, "%s", 0, 6, 1, 0, languageText_fr, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 132}
     };
 // mainMenu = { "Menu principal", 10, mainOpts, TRUE, FALSE};
     mainMenu.title = "Menu principal";
@@ -612,7 +612,7 @@ if (global->language == LANGUAGE_GERMAN)
       { "Landschaft", NULL, WHITE, (double*)&env->landType, NULL, "%s", 0, 7, 1, LANDTYPE_HILLS, landTypeText_de, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight+ 72},
       { "Reihenfolge", NULL, WHITE, (double*)&global->turntype, NULL, "%s", 0, 3, 1, TURN_RANDOM, turnTypeText_de, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 92},
       { "Überspringe Nur-KI", NULL, WHITE, &global->skipComputerPlay, NULL, "%s", 0, 1, 1, 1, skipTypeText_de, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 112},
-      { "Sprache", NULL, WHITE, &global->language, NULL, "%s", 0, 5, 1, 0, languageText_de,OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 132}
+      { "Sprache", NULL, WHITE, &global->language, NULL, "%s", 0, 6, 1, 0, languageText_de,OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 132}
     };
 // mainMenu = { "Hauptmenü", 10, mainOpts, TRUE, FALSE};
     mainMenu.title = "Hauptmenü";
@@ -724,7 +724,7 @@ if (global->language == LANGUAGE_SLOVAK)
       { "Krajina", NULL, WHITE, (double*)&env->landType, NULL, "%s", 0, 7, 1, LANDTYPE_HILLS, landTypeText_sk, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 72},
       { "Poradie", NULL, WHITE, (double*)&global->turntype, NULL, "%s", 0, 3, 1, TURN_RANDOM, turnTypeText_sk, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 92},
       { "Preskočiť hru samotného PC", NULL, WHITE, &global->skipComputerPlay, NULL, "%s", 0, 1, 1, 1, skipTypeText_sk, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 112},
-      { "Jazyk", NULL, WHITE, &global->language, NULL, "%s", 0, 5, 1, 0, languageText_sk, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 132}
+      { "Jazyk", NULL, WHITE, &global->language, NULL, "%s", 0, 6, 1, 0, languageText_sk, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 132}
     };
     mainMenu.title = "Hlavné menu";
     mainMenu.numEntries = 12;
@@ -835,7 +835,7 @@ if (global->language == LANGUAGE_RUSSIAN)
       { "Тип ландшафта", NULL, WHITE, (double*)&env->landType, NULL, "%s", 0, 7, 1, LANDTYPE_HILLS, landTypeText_ru, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 72},
       { "Порядок хода", NULL, WHITE, (double*)&global->turntype, NULL, "%s", 0, 3, 1, TURN_RANDOM, turnTypeText_ru, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 92},
       { "Пропускать игру компьютеров", NULL, WHITE, &global->skipComputerPlay, NULL, "%s", 0, 1, 1, 1, skipTypeText_ru, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 112},
-      { "Язык (Language)", NULL, WHITE, &global->language, NULL, "%s", 0, 5, 1, 0, languageText_ru, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 132}
+      { "Язык (Language)", NULL, WHITE, &global->language, NULL, "%s", 0, 6, 1, 0, languageText_ru, OPTION_SPECIALTYPE, FALSE, global->halfWidth - 3, global->halfHeight + 132}
     };
 // mainMenu = { "Main Menu", 10, mainOpts, TRUE, FALSE};
      mainMenu.title = "Главное меню";
