@@ -580,10 +580,8 @@ int TANK::applyPhysics (GLOBALDATA *global)
         {
           //count damage and add money
           damage = (int) (yv * 10);
-          /*TEST*/
           if (damage >= 10)
-            /*TEST*/		damage -= 10;
-          /*TEST*/
+            damage -= 10;
           else damage = 0;
           creditTo = NULL;
           yv = 0;
@@ -605,8 +603,13 @@ int TANK::applyPhysics (GLOBALDATA *global)
           if ( (delay_fall > 0) && (_env->landSlideType == LANDSLIDE_CARTOON) )
             return stable;
 
+          #ifdef OLD_GAMELOOP
           if (para && para < 3 && !_env->pclock)
             para++;
+          #else
+          if ( (para) && (para < 3) )
+            para++;
+          #endif
           if (!para)
             {
               yv += _env->gravity * (100.0 / _global->frames_per_second);
@@ -625,7 +628,6 @@ int TANK::applyPhysics (GLOBALDATA *global)
           // falling, deploy parachute
           if (!para)
             {
-              /*TEST*/
               if ((player->ni[ITEM_PARACHUTE]) && (yv >= 1.0))
                 {
                   _env->pclock = 1;
@@ -1024,12 +1026,12 @@ void TANK::activateCurrentSelection ()
                 newmis->player = player;
               }
               else
-                  perror ( (char *)"tank.cc: Failed allocating memory for newmis in TANK::activateCurrentSelection");
+                  perror ( "tank.cc: Failed allocating memory for newmis in TANK::activateCurrentSelection");
               // set up volley
               if (! fire_another_shot)
                 {
-                  fire_another_shot = weapon[cw].delay * VOLLY_DELAY;
-                  if ( weapon[cw].delay )
+                    fire_another_shot = weapon[cw].delay * VOLLY_DELAY;
+                    if ( weapon[cw].delay )
                     {
                       shots_fired = shots_fired - (weapon[cw].delay - 1);
                     }
@@ -1406,3 +1408,23 @@ void TANK::setEnvironment(ENVIRONMENT *env)
 }
 
 
+/*
+Give credit to the tank who killed us.
+*/
+void TANK::Give_Credit(GLOBALDATA *global)
+{
+     if (creditTo)
+     {
+        // we shot ourselves
+        if (creditTo == player)
+           creditTo->money -= (int) global->scoreUnitSelfDestroy;
+        else   // we were killed by someone else
+           creditTo->money += (int) global->scoreUnitDestroyBonus;
+
+        // avoid over-flow
+        if (creditTo->money < 0)
+            creditTo->money = 0;
+        creditTo = NULL;
+     }
+}
+
