@@ -48,11 +48,35 @@ TELEPORT::TELEPORT (GLOBALDATA *global, ENVIRONMENT *env, VIRTUAL_OBJECT *target
   remote = new TELEPORT (global, env, this, destinationX, destinationY);
   if (!remote)
     {
-      perror ( (char *)"teleport.cc: Failed allocating memory for remote in TELEPORT::TELEPORT");
+      perror ( "teleport.cc: Failed allocating memory for remote in TELEPORT::TELEPORT");
     }
   play_sample ((SAMPLE *) _global->sounds[item[ITEM_TELEPORT].sound], 255, 128, 1000, 0);
+
+  #ifdef NETWORK
+  // this seems to be the teleport we usually use
+  char buffer[64];
+  int player_index = 0;
+  bool found = false;
+  TANK *the_tank = (TANK*) targetObj;
+  // match the player with the tank
+  while ( (player_index < global->numPlayers) && (! found) )
+  {
+      if ( ( global->players[player_index]->tank ) && (global->players[player_index]->tank == the_tank) )
+        found = true;
+     else
+        player_index++;
+  }
+  if (found)
+  {
+     sprintf(buffer, "TELEPORT %d %d %d", player_index, destinationX, destinationY);
+     global->Send_To_Clients(buffer);
+  }
+  #endif
 }
 
+
+
+
 TELEPORT::TELEPORT (GLOBALDATA *global, ENVIRONMENT *env, TELEPORT *remoteEnd, int destX, int destY):VIRTUAL_OBJECT(),
                     clock(remoteEnd->startClock),startClock(remoteEnd->startClock),peaked(0)
 {
